@@ -1,3 +1,4 @@
+from datetime import datetime
 import time
 from urllib.parse import urlencode
 
@@ -41,10 +42,10 @@ class Jamf:
         """
         Set token and token expiration
         """
-        r = self.http_request(POST, 'api/auth/tokens', headers={},
-                              username=self.username, password=self.password)
+        r = self.http_request(POST, 'api/v1/auth/token', headers={})
         self._token = r.json()['token']
-        self._token_expires = float(r.json()['expires']) / 1000
+        expire_dt = datetime.strptime(r.json()['expires'] ,'%Y-%m-%dT%H:%M:%S.%fZ')
+        self._token_expires = expire_dt.timestamp() / 1000
 
     @property
     def token(self):
@@ -182,16 +183,27 @@ class Jamf:
         """
         url = self.build_url(path, params)
         headers = headers is None and self.get_headers(uapi=uapi) or headers
-        response = Request(
-            url=url,
-            headers=headers,
-            username=kwargs.get('username', None),
-            password=kwargs.get('password', None),
-        ).request(
-            method=verb,
-            url=url,
-            data=post_data,
-        )
+        if path.endswith('token'):
+            response = Request(
+                url=url,
+                headers=headers,
+                username=self.username,
+                password=self.password,
+            ).request(
+                method=verb,
+                url=url,
+                data=post_data,
+            )
+        else:
+            response = Request(
+                url=url,
+                headers=headers,
+                token=self._token,
+            ).request(
+                method=verb,
+                url=url,
+                data=post_data,
+            )
 
         if not response.ok:
             try:
